@@ -1,13 +1,15 @@
 from nonebot import on_command, get_driver
-from nonebot.adapters.onebot.v11 import Bot, Message, MessageSegment, GroupMessageEvent, GROUP, GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.onebot.v11 import Bot, Message, MessageSegment, PrivateMessageEvent, GroupMessageEvent, GROUP, GROUP_ADMIN, GROUP_OWNER
 from nonebot.params import CommandArg
 from nonebot.plugin import PluginMetadata
 from nonebot.permission import SUPERUSER
 from nonebot_plugin_apscheduler import scheduler
 from nonebot_plugin_txt2img import Txt2Img
 from httpx import AsyncClient
+from typing import Union
 from .config import Config
 
+# 插件元数据
 __plugin_meta__ = PluginMetadata(
     'Apex API Query',
     'Apex Legends API 查询插件',
@@ -25,12 +27,13 @@ __plugin_meta__ = PluginMetadata(
     '''
 )
 
+# 读取配置
 plugin_config = Config.parse_obj(get_driver().config)
-
 api_key = plugin_config.apex_api_key
 api_url = plugin_config.apex_api_url
 api_t2i = plugin_config.apex_api_t2i
 
+# 创建事件响应器
 player_statistics = on_command('bridge', aliases= {'玩家'})
 uid_statistics = on_command('uid', aliases={'UID'})
 map_protation = on_command('maprotation', aliases={'地图'})
@@ -44,7 +47,7 @@ unsub_craft = on_command('unsubcraft', aliases={'取消订阅制造'}, permissio
 
 # 玩家名称查询
 @player_statistics.handle()
-async def _(player_name: Message = CommandArg()):
+async def _(bot: Bot, event: Union[PrivateMessageEvent, GroupMessageEvent], player_name: Message = CommandArg()):
     service = 'bridge'
     payload = {'auth': api_key, 'player': str(player_name), 'platform': 'PC'}
     await player_statistics.send('正在查询: 玩家 {}'.format(player_name))
@@ -57,7 +60,7 @@ async def _(player_name: Message = CommandArg()):
 
 # 玩家 UID 查询
 @uid_statistics.handle()
-async def _(player_name: Message = CommandArg()):
+async def _(bot: Bot, event: Union[PrivateMessageEvent, GroupMessageEvent], player_name: Message = CommandArg()):
     service = 'bridge'
     payload = {'auth': api_key, 'uid': str(player_name), 'platform': 'PC'}
     await uid_statistics.send('正在查询: UID {}'.format(player_name))
@@ -70,7 +73,7 @@ async def _(player_name: Message = CommandArg()):
 
 # 地图轮换查询
 @map_protation.handle()
-async def _():
+async def _(bot: Bot, event: Union[PrivateMessageEvent, GroupMessageEvent]):
     service = 'maprotation'
     payload = {'auth': api_key, 'version': '2'}
     await map_protation.send('正在查询: 地图轮换')
@@ -83,7 +86,7 @@ async def _():
 
 # 顶尖猎杀者查询
 @predator.handle()
-async def _():
+async def _(bot: Bot, event: Union[PrivateMessageEvent, GroupMessageEvent]):
     service = 'predator'
     payload = {'auth': api_key}
     await predator.send('正在查询: 顶尖猎杀者')
@@ -96,7 +99,7 @@ async def _():
 
 # 制造轮换查询
 @crafting_rotation.handle()
-async def _():
+async def _(bot: Bot, event: Union[PrivateMessageEvent, GroupMessageEvent]):
     service = 'crafting'
     payload = {'auth': api_key}
     await crafting_rotation.send('正在查询: 制造轮换')
@@ -109,7 +112,7 @@ async def _():
 
 # 服务器状态查询
 @servers.handle()
-async def _():
+async def _(bot: Bot, event: Union[PrivateMessageEvent, GroupMessageEvent]):
     service = 'servers'
     payload = {'auth': api_key}
     await servers.send('正在查询: 服务器状态')
@@ -148,7 +151,7 @@ async def submap(bot, group_id, api_t2i):
 
 # 取消订阅地图轮换
 @unsub_map.handle()
-async def _(event: GroupMessageEvent):
+async def _(bot: Bot, event: GroupMessageEvent):
     try:
         scheduler.remove_job(job_id=(str(event.group_id) + '_map'))
         await unsub_map.send('已取消订阅地图轮换')
@@ -183,7 +186,7 @@ async def subcraft(bot, group_id, api_t2i):
 
 # 取消订阅制造轮换
 @unsub_craft.handle()
-async def _(event: GroupMessageEvent):
+async def _(bot: Bot, event: GroupMessageEvent):
     try:
         scheduler.remove_job(job_id=(str(event.group_id) + '_craft'))
         await unsub_craft.send('已取消订阅制造轮换')
@@ -206,16 +209,7 @@ async def api_query(service, payload):
 
 # txt2img
 def t2i(service, response):
-    if service == 'bridge':
-        title = '玩家查询'
-    elif service == 'maprotation':
-        title = '地图轮换'
-    elif service == 'predator':
-        title = '顶尖猎杀者'
-    elif service == 'crafting':
-        title = '制造轮换'
-    elif service == 'servers':
-        title = '服务器状态'
+    title = convert(service)
     font_size = 32
     text = response
     Txt2Img().set_font_size(font_size)
@@ -243,8 +237,6 @@ def process(service, response):
             '最后封禁原因: {}\n'
             '大逃杀分数: {}\n'
             '大逃杀段位: {} {}\n'
-            '竞技场分数: {}\n'
-            '竞技场段位: {} {}\n'
             '大厅状态: {}\n'
             '在线: {}\n'
             '游戏中: {}\n'
@@ -265,9 +257,6 @@ def process(service, response):
                 globals.get('rank').get('rankScore'),
                 convert(globals.get('rank').get('rankName')),
                 globals.get('rank').get('rankDiv'),
-                globals.get('arena').get('rankScore'),
-                convert(globals.get('arena').get('rankName')),
-                globals.get('arena').get('rankDiv'),
                 convert(realtime.get('lobbyState')),
                 convert(realtime.get('isOnline')),
                 convert(realtime.get('isInGame')),
@@ -283,23 +272,18 @@ def process(service, response):
     # 地图轮换数据
     elif service == 'maprotation':
         battle_royale = response.json().get('battle_royale')
-        arenas = response.json().get('arenas')
         ranked = response.json().get('ranked')
-        arenasRanked = response.json().get('arenasRanked')
+        ltm = response.json().get('ltm')
         data = (
             '大逃杀:\n'
             '当前地图: {}\n'
             '下个地图: {}\n'
             '剩余时间: {}\n\n'
-            '竞技场:\n'
-            '当前地图: {}\n'
-            '下个地图: {}\n'
-            '剩余时间: {}\n\n'
             '排位赛联盟:\n'
             '当前地图: {}\n'
             '下个地图: {}\n'
             '剩余时间: {}\n\n'
-            '排位竞技场:\n'
+            '限时:\n'
             '当前地图: {}\n'
             '下个地图: {}\n'
             '剩余时间: {}'
@@ -307,15 +291,12 @@ def process(service, response):
                 convert(battle_royale.get('current').get('map')),
                 convert(battle_royale.get('next').get('map')),
                 convert(battle_royale.get('current').get('remainingTimer')),
-                convert(arenas.get('current').get('map')),
-                convert(arenas.get('next').get('map')),
-                convert(arenas.get('current').get('remainingTimer')),
                 convert(ranked.get('current').get('map')),
                 convert(ranked.get('next').get('map')),
                 convert(ranked.get('current').get('remainingTimer')),
-                convert(arenasRanked.get('current').get('map')),
-                convert(arenasRanked.get('next').get('map')),
-                convert(arenasRanked.get('current').get('remainingTimer'))
+                convert(ltm.get('current').get('map')),
+                convert(ltm.get('next').get('map')),
+                convert(ltm.get('current').get('remainingTimer'))
             )
         )
         return data
@@ -323,7 +304,6 @@ def process(service, response):
     # 顶尖猎杀者数据
     elif service == 'predator':
         rp = response.json().get('RP')
-        ap = response.json().get('AP')
         data = (
             '大逃杀:\n'
             'PC 端:\n'
@@ -345,27 +325,6 @@ def process(service, response):
             '顶尖猎杀者人数: {}\n'
             '顶尖猎杀者分数: {}\n'
             '顶尖猎杀者UID: {}\n'
-            '大师和顶尖猎杀者人数: {}\n\n'
-            '竞技场:\n'
-            'PC 端:\n'
-            '顶尖猎杀者人数: {}\n'
-            '顶尖猎杀者分数: {}\n'
-            '顶尖猎杀者UID: {}\n'
-            '大师和顶尖猎杀者人数: {}\n'
-            'PS4/5 端:\n'
-            '顶尖猎杀者人数: {}\n'
-            '顶尖猎杀者分数: {}\n'
-            '顶尖猎杀者UID: {}\n'
-            '大师和顶尖猎杀者人数: {}\n'
-            'Xbox 端:\n'
-            '顶尖猎杀者人数: {}\n'
-            '顶尖猎杀者分数: {}\n'
-            '顶尖猎杀者UID: {}\n'
-            '大师和顶尖猎杀者人数: {}\n'
-            'Switch 端:\n'
-            '顶尖猎杀者人数: {}\n'
-            '顶尖猎杀者分数: {}\n'
-            '顶尖猎杀者UID: {}\n'
             '大师和顶尖猎杀者人数: {}'
             .format(
                 rp.get('PC').get('foundRank'),
@@ -384,22 +343,6 @@ def process(service, response):
                 rp.get('SWITCH').get('val'),
                 rp.get('SWITCH').get('uid'),
                 rp.get('SWITCH').get('totalMastersAndPreds'),
-                ap.get('PC').get('foundRank'),
-                ap.get('PC').get('val'),
-                ap.get('PC').get('uid'),
-                ap.get('PC').get('totalMastersAndPreds'),
-                ap.get('PS4').get('foundRank'),
-                ap.get('PS4').get('val'),
-                ap.get('PS4').get('uid'),
-                ap.get('PS4').get('totalMastersAndPreds'),
-                ap.get('X1').get('foundRank'),
-                ap.get('X1').get('val'),
-                ap.get('X1').get('uid'),
-                ap.get('X1').get('totalMastersAndPreds'),
-                ap.get('SWITCH').get('foundRank'),
-                ap.get('SWITCH').get('val'),
-                ap.get('SWITCH').get('uid'),
-                ap.get('SWITCH').get('totalMastersAndPreds')
             )
         )
         return data
@@ -536,7 +479,7 @@ def convert(name):
         'World\'s Edge': '世界尽头',
         'Olympus': '奥林匹斯',
         'Storm Point': '风暴点',
-        'Broken Moon': '破碎月亮',
+        'Broken Moon': '残月',
         'Encore': '再来一次',
         'Habitat': '栖息地 4',
         'Overflow': '熔岩流',
@@ -698,5 +641,11 @@ def convert(name):
         'DOWN': '离线',
         'SLOW': '缓慢',
         'OVERLOADED': '过载',
+        # Plugin
+        'bridge': '玩家查询',
+        'maprotation': '地图轮换',
+        'predator': '顶尖猎杀者',
+        'crafting': '制造轮换',
+        'servers': '服务器状态'
     }
     return names.get(name, name)
