@@ -3,4 +3,5 @@ from typing import Optional
 
 class Config(BaseModel, extra=Extra.ignore):
     apex_api_key: Optional[str] = None
-    apex_api_url = 'https://api.mozambiquehe.re/'
\ No newline at end of file
+    apex_api_url: str = 'https://api.mozambiquehe.re/'
+    apex_api_t2i: bool = True
